# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: routerrpc/router.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='routerrpc/router.proto',
  package='routerrpc',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x16routerrpc/router.proto\x12\trouterrpc\"\x82\x01\n\x0ePaymentRequest\x12\x0f\n\x07pay_req\x18\x01 \x01(\t\x12\x15\n\rfee_limit_sat\x18\x02 \x01(\x03\x12\x12\n\ncltv_limit\x18\x03 \x01(\x05\x12\x17\n\x0ftimeout_seconds\x18\x04 \x01(\x05\x12\x1b\n\x13outgoing_channel_id\x18\x05 \x01(\x03\"K\n\x0fPaymentResponse\x12\x10\n\x08pay_hash\x18\x01 \x01(\x0c\x12\x11\n\tpre_image\x18\x02 \x01(\x0c\x12\x13\n\x0bpayment_err\x18\x03 \x01(\t\"0\n\x0fRouteFeeRequest\x12\x0c\n\x04\x64\x65st\x18\x01 \x01(\x0c\x12\x0f\n\x07\x61mt_sat\x18\x02 \x01(\x03\"E\n\x10RouteFeeResponse\x12\x18\n\x10routing_fee_msat\x18\x01 \x01(\x03\x12\x17\n\x0ftime_lock_delay\x18\x02 \x01(\x03\x32\x9b\x01\n\x06Router\x12\x44\n\x0bSendPayment\x12\x19.routerrpc.PaymentRequest\x1a\x1a.routerrpc.PaymentResponse\x12K\n\x10\x45stimateRouteFee\x12\x1a.routerrpc.RouteFeeRequest\x1a\x1b.routerrpc.RouteFeeResponseb\x06proto3')
)




_PAYMENTREQUEST = _descriptor.Descriptor(
  name='PaymentRequest',
  full_name='routerrpc.PaymentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pay_req', full_name='routerrpc.PaymentRequest.pay_req', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_limit_sat', full_name='routerrpc.PaymentRequest.fee_limit_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cltv_limit', full_name='routerrpc.PaymentRequest.cltv_limit', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout_seconds', full_name='routerrpc.PaymentRequest.timeout_seconds', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outgoing_channel_id', full_name='routerrpc.PaymentRequest.outgoing_channel_id', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=38,
  serialized_end=168,
)


_PAYMENTRESPONSE = _descriptor.Descriptor(
  name='PaymentResponse',
  full_name='routerrpc.PaymentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pay_hash', full_name='routerrpc.PaymentResponse.pay_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pre_image', full_name='routerrpc.PaymentResponse.pre_image', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payment_err', full_name='routerrpc.PaymentResponse.payment_err', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=245,
)


_ROUTEFEEREQUEST = _descriptor.Descriptor(
  name='RouteFeeRequest',
  full_name='routerrpc.RouteFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dest', full_name='routerrpc.RouteFeeRequest.dest', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amt_sat', full_name='routerrpc.RouteFeeRequest.amt_sat', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=295,
)


_ROUTEFEERESPONSE = _descriptor.Descriptor(
  name='RouteFeeResponse',
  full_name='routerrpc.RouteFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routing_fee_msat', full_name='routerrpc.RouteFeeResponse.routing_fee_msat', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_lock_delay', full_name='routerrpc.RouteFeeResponse.time_lock_delay', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=366,
)

DESCRIPTOR.message_types_by_name['PaymentRequest'] = _PAYMENTREQUEST
DESCRIPTOR.message_types_by_name['PaymentResponse'] = _PAYMENTRESPONSE
DESCRIPTOR.message_types_by_name['RouteFeeRequest'] = _ROUTEFEEREQUEST
DESCRIPTOR.message_types_by_name['RouteFeeResponse'] = _ROUTEFEERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PaymentRequest = _reflection.GeneratedProtocolMessageType('PaymentRequest', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentRequest)
  ))
_sym_db.RegisterMessage(PaymentRequest)

PaymentResponse = _reflection.GeneratedProtocolMessageType('PaymentResponse', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTRESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.PaymentResponse)
  ))
_sym_db.RegisterMessage(PaymentResponse)

RouteFeeRequest = _reflection.GeneratedProtocolMessageType('RouteFeeRequest', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEEREQUEST,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeRequest)
  ))
_sym_db.RegisterMessage(RouteFeeRequest)

RouteFeeResponse = _reflection.GeneratedProtocolMessageType('RouteFeeResponse', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEFEERESPONSE,
  __module__ = 'routerrpc.router_pb2'
  # @@protoc_insertion_point(class_scope:routerrpc.RouteFeeResponse)
  ))
_sym_db.RegisterMessage(RouteFeeResponse)



_ROUTER = _descriptor.ServiceDescriptor(
  name='Router',
  full_name='routerrpc.Router',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=369,
  serialized_end=524,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPayment',
    full_name='routerrpc.Router.SendPayment',
    index=0,
    containing_service=None,
    input_type=_PAYMENTREQUEST,
    output_type=_PAYMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='EstimateRouteFee',
    full_name='routerrpc.Router.EstimateRouteFee',
    index=1,
    containing_service=None,
    input_type=_ROUTEFEEREQUEST,
    output_type=_ROUTEFEERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_ROUTER)

DESCRIPTOR.services_by_name['Router'] = _ROUTER

# @@protoc_insertion_point(module_scope)
